#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-sqlite
version:              2.11.0.0
visibility:           public
id:                   persistent-sqlite-2.11.0.0-EPZQUETWHzw4rvlWRdq58I
key:                  persistent-sqlite-2.11.0.0-EPZQUETWHzw4rvlWRdq58I
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.

category:             Database, Yesod
abi:                  33c7646e2b0a7c9e59c60527b44ce1e7
exposed:              True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/persistent-sqlite-2.11.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/persistent-sqlite-2.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/persistent-sqlite-2.11.0.0
hs-libraries:         HSpersistent-sqlite-2.11.0.0-EPZQUETWHzw4rvlWRdq58I
extra-libraries:      pthread sqlite3
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2 base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.4-LKkovHkWTkK2IXYqvxsWMR
    containers-0.6.2.1 microlens-th-0.4.3.8-6syMvL1AliOLD345pvkoxO
    monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
    persistent-2.11.0.2-743j6nHYeNr8Viijc4VTba
    resource-pool-0.2.3.2-HqitEUDO3f643Cz8cjPKzC
    resourcet-1.2.4.2-E1PquPTZKgvLbHxPSs1hvZ text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2 unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX

haddock-interfaces:
    /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

